(function( $ ) {
	'use strict';

	/**
	 * All of the code for your admin-facing JavaScript source
	 * should reside in this file.
	 *
	 * Note: It has been assumed you will write jQuery code here, so the
	 * $ function reference has been prepared for usage within the scope
	 * of this function.
	 *
	 * This enables you to define handlers, for when the DOM is ready:
	 *
	 * $(function() {
	 *
	 * });
	 *
	 * When the window is loaded:
	 *
	 * $( window ).load(function() {
	 *
	 * });
	 *
	 * ...and/or other possibilities.
	 *
	 * Ideally, it is not considered best practise to attach more than a
	 * single DOM-ready or window-load handler for a particular page.
	 * Although scripts in the WordPress core, Plugins and Themes may be
	 * practising this, we should strive to set a better example in our own work.
	 */

	// Background image uploader instance.
    var backgroundImageUploader;

    $('#background_image_upload_button').click(function(e) {
        e.preventDefault();

        // If the uploader object has already been created, reopen the dialog
        if (backgroundImageUploader) {
            backgroundImageUploader.open();
            return;
        }

        // Media uploader settings to customize media uploader.
        backgroundImageUploader = wp.media.frames.file_frame = wp.media({
            title: 'Choose Background Image',
            library : {
                type : 'image'
            },
            button: {
                text: 'Select Image'
            },
            multiple: false
        });

        // When a file is selected, grab the URL and set it as the text field's value.
        backgroundImageUploader.on('select', function() {
            var attachment = backgroundImageUploader.state().get('selection').first().toJSON();
            $('#csp_album_background_image_url').val(attachment.url);

            // Prepare the attachment object.
            var selection = {};
            selection[attachment.id] = attachment.url;

            $('#csp_album_background_image').val(JSON.stringify(selection) );
        });

        // Get the selected image.
        var selected = JSON.parse($('#csp_album_background_image').val());

        // Mark the current selection in uploader modal.
        markAlreadySelectedImages(backgroundImageUploader, selected);

        // Open the uploader dialog.
        backgroundImageUploader.open();
    });

    // Gallery image uploader instance.
	var galleryImageUploader;

    $('#gallery_image_upload_button').click(function(e) {
        e.preventDefault();

        // If the uploader object has already been created, reopen the dialog
        if (galleryImageUploader) {
            galleryImageUploader.open();
            return;
        }

        // Media uploader settings to customize media uploader.
        galleryImageUploader = wp.media.frames.file_frame = wp.media({
            title: 'Choose Gallery Images',
            library : {
                type : 'image'
            },
            button: {
                text: 'Select Images'
            },
            multiple: 'add'
        });
        let maxImages = 10;
        // When a file is selected, grab the URL and set it as the text field's value.
        galleryImageUploader.on('select', function() {
            let selection = galleryImageUploader.state().get('selection');
            let attachment_ids = selection.pluck('id');

            if (attachment_ids.length > maxImages) {
                alert('You can only select up to ' + maxImages + ' images.');
                selection.reset(); // Reset the selection if exceeded limit
            }
            // Prepare the attachments array.
            var attachments = {};

            selection.map(function (attachment) {
                attachment.toJSON();
                attachments[attachment.attributes.id] = attachment.attributes.url;
            });
            
            // Store the attachments object in HTML.
            $('#csp_album_images').val(JSON.stringify(attachments));

            // Images container.
            var imagesContainer = $('#csp_admin_image_gallery_wrapper');

            // Clear the container.
            imagesContainer.html('');

            // Loop through the attachments and show in the selection area.
            for (var imageId in attachments) {

                // Put the images.
                $('<div class="csp_admin_single_image_as_thumb" id="single_image_"' + imageId + '>' +
                                        '<img class="csp_admin_single_image" src="' + attachments[imageId] + '">' +
                                        '<input type="button" class="csp_admin_gallery_remove_image"  value="X" data-id="' + imageId + '"/>' +
                                    '</div>').appendTo(imagesContainer);

            }

        });

        // Get the already selected images.
        var currentImages = JSON.parse($('#csp_album_images').val());

        // Mark already selected images in the uploader modal.
        markAlreadySelectedImages(galleryImageUploader, currentImages);

        // Open the uploader dialog.
        galleryImageUploader.open();
    });

    // On click of remove icon.
    $(document).on('click', '.csp_admin_gallery_remove_image', function (e) {

        // Get the data id.
        var imageId = $(this).data('id');

        // Get the selection object.
        var currentImages = JSON.parse($('#csp_album_images').val());

        // Remove the image from selection object.
        delete currentImages[imageId];

        // Store new selection object in HTML.
        $('#csp_album_images').val(JSON.stringify(currentImages));

        // Hide the image from view.
        $(this).parent().hide();

        // Re instantiate the uploader modal to update the selection marks.
        galleryImageUploader = null;

    });

    // If pricing per album is chekced show image selection section.
    $(document).ready(function() {
        if ($('#csp_pricing_per_album').hasClass('checked')) {
            $('#csp_pricing_per_album').attr('checked', true);
            $('#csp_no_of_images_section').css('display', '');
        } else {
            $('#csp_no_of_images_section').css('display', 'none');
        }
    });

    // On change of pricing per selection show or hide the no of images selection.
    $('#csp_pricing_per_album').on('change', function() {
        // If pricing per album is chekced show image selection section else hide.
        if ($('#csp_pricing_per_album').prop('checked')) {
            $('#csp_no_of_images_section').css('display', '')
            $('[name="csp_no_of_image_to_select"]').val(1);
        } else {
            $('#csp_no_of_images_section').css('display', 'none');
            $('[name="csp_no_of_image_to_select"]').val(0);
        }
    });

})( jQuery );

/**
 * Marks already selected images into the wp media uploader modal.
 *
 * @since   1.0.0
 *
 * @param uploader          WP media uploader modal instance.
 * @param selected          Selected media object with the media ids in key.
 */
function markAlreadySelectedImages(uploader, selected) {

    // On opening of the image selection modal.
    uploader.on('open', function() {

        // Get the selection object.
        var selection = uploader.state().get('selection');

        // Loop through all the already selected images.
        for (var id in selected) {
            var attachment = wp.media.attachment(id);
            attachment.fetch();
            selection.add(attachment ? [attachment] : []);
        }

    });
}
