<?php
/**
 * Provide a admin area view for the plugin
 *
 * This file is used to markup the admin-facing aspects of the plugin.
 *
 * @link       https://dreamstyle.photos
 * @since      1.0.0
 *
 * @package    Wp_csp
 * @subpackage Wp_csp/admin/partials
 */

/**
 * The admin-specific view functions of the plugin.
 *
 * @package    Wp_csp
 * @subpackage Wp_csp/admin/partials
 */
class Wp_Csp_Admin_Display {

	/**
	 * Generates album editor HTML content.
	 *
	 * @since   1.0.0
	 *
	 * @param   object $post        Current post object.
	 * @return  string              HTML.
	 */
	public static function get_album_editor_html( $post ) {

		// set nonce field.
		wp_nonce_field( CSP_SAVE_META_BOX_ACTION_NAME, CSP_SAVE_META_BOX_NONCE );

		// Get the images already selected.
		$images = maybe_unserialize( get_post_meta( $post->ID, CSP_ALBUM_IMAGES_META_KEY, true ) );

		// Image HTML to show on the selection viewer section.
		$selected_images_html = '';
		if ( ! empty( $images ) ) {
			foreach ( $images as $id => $url ) {
				$selected_images_html .= '<div class="csp_admin_single_image_as_thumb" id="single_image_"' . $id . '><img class="csp_admin_single_image" src="' . $url . '">
                                        <input type="button" class="csp_admin_gallery_remove_image"  value="X" data-id="' . $id . '"/>
                                    </div>';

			}
		}

		$no_of_pics        = esc_html( get_post_meta( $post->ID, CSP_NO_OF_IMAGE_TO_SELECT_META_KEY, true ) );
		$pricing_per_album = empty( esc_html( get_post_meta( $post->ID, CSP_PRICING_PER_ALBUM_META_KEY, true ) ) ) ? '' : 'checked';
		$note              = '<div class="csp_admin_inputboxes" style="padding: 15px;">
                    <p style="font-size: 0.8em !important;">' . __( 'In the "Client album User-Code" field, you can freely select a code (numbers and letters) that the users should receive. This code must be unique.', 'wp_csp' ) . '</p>
                    <p style="font-size: 0.8em !important;">' . __( 'With the "Gallery selection" photos are uploaded, which should be contained in the album.', 'wp_csp' ) . '</p>
                    <p style="font-size: 0.8em !important;">' . __( 'The checkbox differentiates whether this album should be a e.g. 5 photos at the package price of 19.99 € or whether any number should be sold at the price of e.g. 2.50 €.', 'wp_csp' ) . '</p>
                    <p style="font-size: 0.8em !important;">' . __( 'A description for the user can be inserted in the hint text.', 'wp_csp' ) . '</p>
                </div>';

		$output = '
            <table width="100%" border="0">
                <tbody>
                    <tr>
                        <td colspan="2" class="' . CSP_PLUGIN_PREFIX . '_admin_td">
                            ' . $note . '
                        </td>
                    </tr>
                    <tr>
                        <!-- Client album User-Code -->
                        <td class="' . CSP_PLUGIN_PREFIX . '_admin_td"><lable for="' . CSP_ALBUM_SECRET_CODE_META_KEY . '">' . __( 'Client album User-Code', 'wp_csp' ) . '</lable> </td>
                        <td class="' . CSP_PLUGIN_PREFIX . '_admin_td"><input class="' . CSP_PLUGIN_PREFIX . '_admin_inputboxes csp_admin_inputboxes_text_center" type="text" name="' . CSP_ALBUM_SECRET_CODE_META_KEY . '" value="' . esc_html( get_post_meta( $post->ID, CSP_ALBUM_SECRET_CODE_META_KEY, true ) ) . '" /> </td>
                    </tr>
                    <tr>
                        <!-- Client album picture selecter -->
                        <td class="' . CSP_PLUGIN_PREFIX . '_admin_td">
                            <input id="gallery_image_upload_button" type="button" class="button button-primary" value="' . __( 'Gallery selection', 'wp_csp' ) . '" />
                            <input type="hidden" id="' . CSP_ALBUM_IMAGES_META_KEY . '" name="' . CSP_ALBUM_IMAGES_META_KEY . '" value="' . esc_html( wp_json_encode( $images ) ) . '" />
                        </td>
                        <td class="' . CSP_PLUGIN_PREFIX . '_admin_td">
                            <div id="csp_admin_image_gallery_wrapper">' . $selected_images_html . '</div>
                        </td>
                    </tr>
                    <tr>
                        <!-- Pricing per album selection -->
                        <td class="' . CSP_PLUGIN_PREFIX . '_admin_td"><lable for="' . CSP_PRICING_PER_ALBUM_META_KEY . '">' . __( 'If checked: Pricing per album will be set. (If unchecked: Selection will rise the amount of the product.)', 'wp_csp' ) . '</lable> </td>
                        <td class="' . CSP_PLUGIN_PREFIX . '_admin_td"><input id="csp_pricing_per_album" type="checkbox" class="' . CSP_PLUGIN_PREFIX . '_admin_inputboxes csp_admin_inputboxes_text_center ' . $pricing_per_album . '" name="' . CSP_PRICING_PER_ALBUM_META_KEY . '" value="1" ' . $pricing_per_album . ' /> </td>
                    </tr>
                    <tr id="csp_no_of_images_section" style="display: none;">
                        <!-- Client album - Amount of images for selecting from the shop user during the order -->
                        <td class="' . CSP_PLUGIN_PREFIX . '_admin_td"><lable for="' . CSP_NO_OF_IMAGE_TO_SELECT_META_KEY . '">' . __( 'Amount of images for selecting from the shop user during the order', 'wp_csp' ) . '</lable> </td>
                        <td class="' . CSP_PLUGIN_PREFIX . '_admin_td"><input class="' . CSP_PLUGIN_PREFIX . '_admin_inputboxes csp_admin_inputboxes_text_center" type="text" name="' . CSP_NO_OF_IMAGE_TO_SELECT_META_KEY . '" value="' . $no_of_pics . '" /> </td>
                    </tr>
                    
                    <tr>
                    
                    <!-- Client album - Hint text during the popup inside product -->
                        <td class="' . CSP_PLUGIN_PREFIX . '_admin_td"><lable for="' . CSP_ALBUM_HINT_TEXT . '">' . __( 'Hint text during the popup inside product', 'wp_csp' ) . '</lable> </td>
                        <td class="' . CSP_PLUGIN_PREFIX . '_admin_td"><textarea class="' . CSP_PLUGIN_PREFIX . '_admin_inputboxes csp_admin_inputboxes_100_percent" id="' . CSP_ALBUM_HINT_TEXT . '" name="' . CSP_ALBUM_HINT_TEXT . '" cols="35" rows="6">' . esc_html( get_post_meta( $post->ID, CSP_ALBUM_HINT_TEXT, true ) ) . '</textarea></td>
                        
                    </tr>
                </tbody>
            </table>
            
            <!-- some space :-) -->
            <p>&nbsp;</p><p>&nbsp;</p><p>&nbsp;</p><p>&nbsp;</p>
		
		';
		return $output;

	}

}
