<?php
/**
 * The file that defines the code for securing resources.
 *
 * A class definition that protects uploaded files with login.
 *
 * @link              https://dreamstyle.photos
 * @since             1.1.0
 * @package           Wp_csp
 */

/**
 * The file that defines the code for securing resources.
 *
 * A class definition that protects uploaded files with login.
 *
 * @package    Wp_csp
 */

require_once '../../../wp-load.php';

is_user_logged_in() || auth_redirect();

list($basedir) = array_values( array_intersect_key( wp_upload_dir(), array( 'basedir' => 1 ) ) ) + array( null );

$get  = $_GET;
$file = rtrim( $basedir, '/' ) . '/' . str_replace( '..', '', isset( $get['file'] ) ? $get['file'] : '' );
if ( ! $basedir || ! is_file( $file ) ) {
	status_header( 404 );
	die( '404 &#8212; File not found.' );
}

$mime = wp_check_filetype( $file );
if ( false === $mime['type'] && function_exists( 'mime_content_type' ) ) {
	$mime['type'] = mime_content_type( $file );
}

if ( $mime['type'] ) {
	$mimetype = $mime['type'];
} else {
	$mimetype = 'image/' . substr( $file, strrpos( $file, '.' ) + 1 );
}

header( 'Content-Type: ' . $mimetype ); // always send this.
$server = $_SERVER;
if ( false === strpos( $server['SERVER_SOFTWARE'], 'Microsoft-IIS' ) ) {
	header( 'Content-Length: ' . filesize( $file ) );
}

$last_modified = gmdate( 'D, d M Y H:i:s', filemtime( $file ) );
$etag          = '"' . md5( $last_modified ) . '"';
header( "Last-Modified: $last_modified GMT" );
header( 'ETag: ' . $etag );
header( 'Expires: ' . gmdate( 'D, d M Y H:i:s', time() + 100000000 ) . ' GMT' );

// Support for Conditional GET.
$client_etag = isset( $server['HTTP_IF_NONE_MATCH'] ) ? stripslashes( $server['HTTP_IF_NONE_MATCH'] ) : false;

if ( ! isset( $server['HTTP_IF_MODIFIED_SINCE'] ) ) {
	$server['HTTP_IF_MODIFIED_SINCE'] = false;
}

$client_last_modified = trim( $server['HTTP_IF_MODIFIED_SINCE'] );
// If string is empty, return 0. If not, attempt to parse into a timestamp.
$client_modified_timestamp = $client_last_modified ? strtotime( $client_last_modified ) : 0;

// Make a timestamp for our most recent modification...
$modified_timestamp = strtotime( $last_modified );

if ( ( $client_last_modified && $client_etag )
	? ( ( $client_modified_timestamp >= $modified_timestamp ) && ( $client_etag == $etag ) )
	: ( ( $client_modified_timestamp >= $modified_timestamp ) || ( $client_etag == $etag ) )
) {
	status_header( 304 );
	exit;
}

// If we made it this far, just serve the file.
readfile( $file );
