(function( $ ) {
	'use strict';

	/**
	 * All of the code for your public-facing JavaScript source
	 * should reside in this file.
	 *
	 * Note: It has been assumed you will write jQuery code here, so the
	 * $ function reference has been prepared for usage within the scope
	 * of this function.
	 *
	 * This enables you to define handlers, for when the DOM is ready:
	 *
	 * $(function() {
	 *
	 * });
	 *
	 * When the window is loaded:
	 *
	 * $( window ).load(function() {
	 *
	 * });
	 *
	 * ...and/or other possibilities.
	 *
	 * Ideally, it is not considered best practise to attach more than a
	 * single DOM-ready or window-load handler for a particular page.
	 * Although scripts in the WordPress core, Plugins and Themes may be
	 * practising this, we should strive to set a better example in our own work.
	 */

    /**
	 * On click of the sectect code button.
     */
	
    $('body').on('click', '#csp_secret_code_button', function (e) {

        // Validate the secret code field.
        if ('' === $('#csp_secret_code_text').val() || undefined === $('#csp_secret_code_text').val()) {

            $('#csp_secret_code_text').focus();

            // Show the error message.
            $('#csp_error_msg_container').text(csp_langvars.validCode);

            return;
		}

        // Get the field values.
		var secretCode = $('#csp_secret_code_text').val();
		var nonce = $('#csp_album_secret_code_nonce_field').val();

        $.ajax({
            method: 'POST',
            url: csp_ajax_url,
            data: {
                action: 'get_album_by_user_code',
                secretCode: secretCode,
                nonce: nonce
            },
            success: function (res) {
                
            	// Parse response json.
            	res = JSON.parse(res);

            	// Check if success.
				if (res.success) {

				    // Clear error message.
                    $('#csp_error_msg_container').text('');

                    // Open the image selection modal.
                    $('#csp_image_selection_modal').modal();
                    $('#csp_modal_error_msg_container').text('');

                    var noOfImagesToSelectText = ( 0 === res.data.no_of_image_to_select ) ? csp_langvars.anyNumber : res.data.no_of_image_to_select;

                    // Show no of images to select and hint text.
					$('#csp_no_of_image_to_select_label').text(noOfImagesToSelectText);
					$('#csp_public_no_of_images_to_select_text').val(res.data.no_of_image_to_select);
					$('#csp_public_album_hint_text').html(res.data.hint_text);

                    // Loop through the images.
                    if (null !== res.data.images) {

                        // Get images.
                        var images = res.data.images;

                        // Clear the image container.
                        $('#csp_public_image_gallery_wrapper').html('');
                        $('#csp_public_image_gallery_wrapper').attr("data-is-pricing-per-album", res.data.is_pricing_per_album);
                        for (var imageId in images) {

                            // Put images in the modal.
                            $('#csp_public_image_gallery_wrapper').append('\n' +
                                '<div class="csp_public_single_image_as_thumb" id="csp_public_single_image_'+ imageId +'">' +
                                    '<a href="#lightbox-image-'+ imageId +'" data-toggle="lightbox" data-max-width="400">' +
                                        '<img class="csp_public_single_image img-fluid" src="'+ images[imageId] +'">' +
                                    '</a>\n' +

                                    '<div id="lightbox-image-'+ imageId +'" class="lightbox fade"  tabindex="-1"' +
                                    'role="dialog" aria-hidden="true">\n' +
                                        '<div class="lightbox-dialog">\n' +
                                            '<div class="lightbox-content">\n' +
                                                '<img src="'+ images[imageId].replace("-100x100.", ".") +'">\n' +
                                            '</div>\n' +
                                        '</div>\n' +
                                    '</div>' +

                                    '<input type="checkbox" class="csp_public_gallery_remove_image csp_public_checkbox"' +
                                    'id="csp_gallery_remove_image_'+ imageId +'" value="'+ images[imageId] +'"' +
                                    'data-id="'+ imageId +'"/>\n' +
                                    '<input type="hidden"></input>'+
                                '</div>');

                        }

                    }

				} else {
                    // Show the error message.
					$('#csp_error_msg_container').text(res.message);

				}

            },
            error: function (err) {
            	console.log(err);
            }
        });
    });

    /**
	 * On submit of the image selection form.
	 */
    $('#csp_public_image_selection_form').on('submit', function (e) {

    	e.preventDefault();

        var selection = {};

        // Get the selected images.
        var selectedImageUrls = $(".csp_public_gallery_remove_image:checked").map(function() {

            // Prepare the selection object.
            selection[$(this).data('id')] = $(this).val();

            return $(this).val();
        }).get();

        var noOfImagesCanBeSelected = parseInt($('#csp_public_no_of_images_to_select_text').val());

        // Validate no of selected images.
        if (0 === selectedImageUrls.length) {
            $('#csp_modal_error_msg_container').text(csp_langvars.selectPhotos);
            return;
        }

        if (0 !== noOfImagesCanBeSelected && noOfImagesCanBeSelected != selectedImageUrls.length) {

            // Show error message.
            $('#csp_modal_error_msg_container').text(csp_langvars.selectExactly + $('#csp_public_no_of_images_to_select_text').val() + ' photos');
            return;
        }

        // Submit button.
		var submitButton = $('#csp_public_image_selection_form .csp_public_button');

        submitButton.text(csp_langvars.please_wait);
        submitButton.prop('disabled', true);
        var pricing_per_album = $('#csp_public_image_gallery_wrapper').attr('data-is-pricing-per-album');

        $.ajax({
            method: 'POST',
            url: csp_ajax_url,
            data: {
                action: 'save_selections',
                selectedImages: selection,
                is_pricing_per_album:pricing_per_album,
                nonce: $('#csp_save_selections_nonce').val()
            },
            success: function (res) {

                // Parse response json.
                res = JSON.parse(res);

                // Check if success.
                if (res.success) {
                    
                	submitButton.text(csp_langvars.select);
                    submitButton.prop('disabled', false);

                    // Show change selection text on button.
                    $('#csp_secret_code_button').text(csp_langvars.changeSelection);

                    // Close the modal.
                    $($('#csp_image_selection_modal').find('.close-modal')[0]).click();
                    // $('#csp_image_selection_modal').dialog("close");

                    // Hide the input box and text lable.
                    $('#csp_user_code_label').css('display', 'none');
                    $('#csp_secret_code_text').css('display', 'none');

                    // Clear the image container.
                    $('#csp_selected_images_container').html('');

                    // If pricing per album.
                    if ( 0 === noOfImagesCanBeSelected ) {

                        // Set cart quantity.
                        $('[name="quantity"]').val(selectedImageUrls.length);

                    }

                    // Show selected images.
                    for (var imageId in selection) {

                        // Put images in the modal.
                        $('#csp_selected_images_container').append('\n' +
                            '<div class="csp_public_single_image_as_thumb" id="csp_public_single_image_'+ imageId +'">' +
                            '<img class="csp_public_single_image" src="'+ selection[imageId] +'">\n' +
                            '</div>');

                    }

                } else {
                    // Show the error message.
                    $('#csp_error_msg_container').text(res.message);

                    // Reset cart quantity.
                    $('[name="quantity"]').val(selectedImageUrls.length);

                }

            },
            error: function (err) {
                console.log(err);
            }

        });

    });

    /** On click of close modal button click the outside of the active modal. */
    $('body').on('click', '.close-modal', function () {
        $('.modal-backdrop').click();
    })

})( jQuery );
