<?php
/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://dreamstyle.photos
 * @since             1.2.1
 * @package           Wp_csp
 *
 * @wordpress-plugin
 * Plugin Name:       Click&Sell Photos
 * Plugin URI:        https://dreamstyle.photos
 * Description:       The easy way to sell your photos on WooCommerce.
 * Version:           1.2.1
 * Author:            Dreamstyle
 * Author URI:        https://dreamstyle.photos
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       wp_csp
 * Domain Path:       /languages
 */

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'WP_CSP_VERSION', '1.0.0' );

/** If some try from outside exit direct */
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-wp-csp-activator.php
 */
function activate_wp_csp() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-wp-csp-activator.php';
	Wp_Csp_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-wp-csp-deactivator.php
 */
function deactivate_wp_csp() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-wp-csp-deactivator.php';
	Wp_Csp_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_wp_csp' );
register_deactivation_hook( __FILE__, 'deactivate_wp_csp' );

/**
 * The file responsible for defining & loading all the constants.
 */
require_once plugin_dir_path( __FILE__ ) . 'includes/constants.php';

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-wp-csp.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_wp_csp() {
	$plugin = new Wp_Csp();
	$plugin->run();
}
run_wp_csp();
